#
# spec file for package rasdaemon
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rasdaemon
Version:        0.6.5+git20200205.3dca35f
Release:        2.8
Summary:        Utility to receive RAS error tracings
License:        GPL-2.0-only
Group:          Hardware/Other
URL:            http://git.infradead.org/users/mchehab/rasdaemon.git
Source:         %{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-devel
BuildRequires:  libtool
BuildRequires:  sqlite3-devel
BuildRequires:  systemd-rpm-macros
Requires:       perl-DBD-SQLite
%{?systemd_requires}
%ifnarch s390x ppc64le
Requires:       dmidecode
%endif

%description
rasdaemon is a RAS (Reliability, Availability and Serviceability) logging tool.
It currently records memory errors, using the EDAC tracing events.
EDAC is drivers in the Linux kernel that handle detection of ECC errors
from memory controllers for most chipsets on i386 and x86_64 architectures.
EDAC drivers for other architectures like arm also exists.
This userspace component consists of an init script which makes sure
EDAC drivers and DIMM labels are loaded at system startup, as well as
an utility for reporting current error counts from the EDAC sysfs files.

%prep
%setup -q

%build
autoreconf -fvi
%configure \
  --enable-mce \
  --enable-aer \
  --enable-sqlite3 \
  --enable-extlog \
  --enable-abrt-report \
  --enable-arm \
  --enable-non-standard \
  --enable-hisi-ns-decode \
  --enable-devlink \
  --enable-diskerror
make %{?_smp_mflags} V=1

%install
%make_install
install -D -p -m 0644 misc/rasdaemon.service %{buildroot}%{_unitdir}/rasdaemon.service
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcrasdaemon
install -D -p -m 0644 misc/ras-mc-ctl.service %{buildroot}%{_unitdir}/ras-mc-ctl.service
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcras-mc-ctl
install -D -p -m 0644 labels/dell %{buildroot}%{_sysconfdir}/ras/dimm_labels.d/dell
rm %{buildroot}%{_includedir}/*.h
mkdir -p %{buildroot}%{_localstatedir}/lib/rasdaemon

%pre
%service_add_pre rasdaemon.service ras-mc-ctl.service

%post
%service_add_post rasdaemon.service ras-mc-ctl.service

%preun
%service_del_preun rasdaemon.service ras-mc-ctl.service

%postun
%service_del_postun rasdaemon.service ras-mc-ctl.service

%files
%license COPYING
%doc AUTHORS ChangeLog README TODO
%{_sbindir}/rasdaemon
%{_sbindir}/ras-mc-ctl
%{_sbindir}/rcrasdaemon
%{_sbindir}/rcras-mc-ctl
%{_mandir}/*/*
%{_unitdir}/*.service
%dir %{_sysconfdir}/ras
%dir %{_localstatedir}/lib/rasdaemon
%ghost %{_localstatedir}/lib/rasdaemon/ras-mc_event.db
%config %{_sysconfdir}/ras/dimm_labels.d

%changelog
* Wed Apr 29 2020 trenn@suse.de
- Let squlite create devlink_event and other tables via configure option
  bsc#1170016, bsc#1170014
* Thu Feb  6 2020 trenn@suse.de
- Update to version 0.6.5+git20200205.3dca35f
- bsc#1162524
  Mainline commits:
  3a4fc059d58d876733d5fd9098b6be9e2a9034d8
  a16ca0711001957ee98f2c124abce0fa1f801529
  which are required for bsc#1162524:
  rasdaemon update with support for AMD scalable MCA and cnamburu-naples-support
* Thu Aug 23 2018 mpluskal@suse.com
- Update to version 0.6.2:
  * Bump to version 0.6.2
  * INSTALL: update it from auto-generated data
  * ChangeLog: Reorder to place new stuff at the beginning
  * rasdaemon: ras-mc-ctl: add option to show error counts
  * mce-amd-k8: be sure to not go past error_msg buffer
  * ras-report: avoid copying after addr.sun_path
  * mce-intel-*: fix a warning when using FIELD(<num>, NULL)
  * rasdaemon: use separate string array for error status
  * rasdaemon: fix PCIe AER error type
* Fri Jun 15 2018 mpluskal@suse.com
- Update to version 0.6.1:
  * Bump version to 0.6.1
  * rasdaemon: Update DIMM labels for 2-socket servers
  * rasdaemon: Add Skylake Xeon MSCOD values
  * rasdaemon: ARM: fully initialize ras_arm_event
  * Update my email
  * mce-intel-p4-p6: prevent build errors with -Werror=format-security
* Thu Apr  5 2018 josef.moellers@suse.com
- Enabled arm and non-standard.
  [bsc#1086520, FATE#323658]
* Wed Jan 17 2018 josef.moellers@suse.com
- Do not require dmidecode on s390x and ppc64le, it does not
  exist there!
  [bsc#1071830]
* Tue Nov 21 2017 eich@suse.com
- Update to version 0.6.0:
  * rasdaemon: Update DIMM labels for Intel Skylake servers
  * rasdaemon:add support for non-standard error decoder
  * rasdaemon:add support for Hisilicon non-standard error decoder
  * configure.ac: show if Hisilicon error report are enabled
  * rasdaemon: add support for ARM events
  * configure.ac: display if ARM error report is enabled
  * rasdaemon: update bugs report information
  * Makefile: add new rasdaemon headers
  * rasdaemon.spec: add other --enable options
  * Bump to version 0.6.0
  (FATE#323162).
* Fri Jun  9 2017 fschnizlein@suse.com
- Update to version 0.5.9:
  * Update it to point to the new repository
  * configure.ac: report enabled features
  * rasdaemon: Update DIMM labels for Dell Servers
  * rasdaemon: add Knights Mill model
  * rasdaemon.spec.in: update it to reflect current needs
* Mon Apr 10 2017 mpluskal@suse.com
- Switch to _service as fedorahosted is retired
- Update project url
- Use macro for systemd dependencies
- Make building more verbose
- Install provided labels for dell
* Tue May 31 2016 fvogt@suse.com
- Update to 0.5.8, obsoleted patches:
  - broadwell_de_mscod.patch
  - broadwell_ep_ex_mscod.patch
* Tue May 31 2016 trenn@suse.de
- Add MSCOD values for broadwell de/ep/ex processors
  * Add broadwell_de_mscod.patch
  * Add broadwell_ep_ex_mscod.patch
* Mon Mar  7 2016 fvogt@suse.com
- Run spec-cleaner: - Change Group and copyright notice
* Mon Mar  7 2016 trenn@suse.de
- Update to version 0.5.7 (including Knights Landing CPU support, fate#319513)
* Fri Nov 27 2015 fvogt@suse.com
- Use provided .tar.xz directly instead of generating one via tar_scm
* Wed Nov 25 2015 trenn@suse.de
- Fix upper case letter issues on requires on package perl-DBD-SQLite
- Create /var/lib/rasdaemon for db file creation at runtime
* Fri Nov  6 2015 fvogt@suse.com
- Disable _service and run manually
* Tue Nov  3 2015 fvogt@suse.com
- Initial commit from git
